#
# spec file for package jedit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _buildshell /bin/bash
%define section	free
Name:           jedit
Version:        5.5.0
Release:        7.3
Summary:        Programmer's Text Editor Written in Java
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://www.jedit.org/
Source0:        http://download.sourceforge.net/jedit/jedit%{version}source.tar.bz2
Source1:        icons.tar
Source2:        %{name}.desktop
Source3:        %{name}.in
Source4:        http://prdownloads.sourceforge.net/jedit-plugins/QuickNotepad-5.0.tgz
#svn co https://jedit.svn.sourceforge.net/svnroot/jedit/build-support/trunk build-support
Source5:        build-support-r22713.tar.gz
Patch0:         jedit-jdk9+.patch
Patch1:         jedit-doclet.patch
BuildRequires:  ant >= 1.8.2
BuildRequires:  ant-apache-bsf
BuildRequires:  ant-contrib
BuildRequires:  ant-junit
BuildRequires:  apache-commons-logging
BuildRequires:  apache-ivy
BuildRequires:  bouncycastle
BuildRequires:  bsh2
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  hamcrest
BuildRequires:  hicolor-icon-theme
BuildRequires:  java-devel >= 1.8
BuildRequires:  jsr-305
BuildRequires:  junit
BuildRequires:  rhino
Recommends:     %{name}-javadoc = %{version}
BuildArch:      noarch

%description
jEdit is a cross-platform programmer's text editor written in Java.
Some of jEdit's features include:

* Built-in macro language (BeanShell).
* Extensible plug-in architecture with more than 80 plug-ins
   available.
* Plug-ins can be downloaded and installed from within jEdit using
   the plug-in manager feature.
* Syntax highlighting for more than 80 languages.
* Supports a large number of character encodings including UTF8 and
   Unicode.
* Auto-indenting of source code.
* Folding (indent and marker based).
* Word wrap.
* Unlimited undo and redo.
* Highly configurable and customizable.
* Every other feature, both basic and advanced, that you would expect
to find in a text editor.

%package javadoc
Summary:        Programmer's text editor written in Java (Documentation)
Group:          Productivity/Text/Editors

%description javadoc
Javadoc for %{summary}.

%prep
%setup -q -D -n jEdit -b 1 -a 4 -a 5
%patch -P 0 -p1
%patch -P 1 -p1

find . -name '*jar' -delete

rm -f doclet/GenerateTocXML.java

%build

DOCBOOK=%{_datadir}/xml/docbook/stylesheet/nwalsh/current

# Specify some properties
cat <<EOF > build.properties
xsltproc.executable=%{_bindir}/xsltproc
docbook.xsl=${DOCBOOK}
docbook.catalog=${DOCBOOK}/catalog.xml
build.support=$(pwd)/build-support/
EOF

# link dependencies
link_dependencies () {
    mkdir -p "$2"
    IFS=':' read -a jars <<< $(build-classpath $1)
    for jar in "${jars[@]}"; do ln -sf "${jar}" "$2/$1-$(basename "${jar}")"; done
}

link_dependencies jsr-305 lib/compile
link_dependencies junit lib/test
link_dependencies hamcrest lib/test
link_dependencies ant lib/ant-contrib
link_dependencies bsh2-bsf lib/scripting

mkdir -p lib/ivy
ln -sf $(build-classpath ivy) lib/ivy/ivy-2.2.0.jar

# we have to break a dependency where build target expects plugins are in place,
# where they are built separatelly and need jEdit.jar for a build
mkdir -p lib/default-plugins/
touch lib/default-plugins/HACK

export CLASSPATH=$(build-classpath apache-commons-logging)
# Run the build
# XXX: there's NPE on build-docs, but who care about html docs those times, right?
%{ant} -Divy.done=true build docs-javadoc
cp -r doc/* build/doc/

# plugins-build hardcodes the jedit.jar path - so to make it happy
ln -s build/jedit.jar

pushd QuickNotepad
%{ant}
popd
mv QuickNotepad.jar build/jars
rm build/jars/HACK

%install
# dirs
install -d -m 0755 %{buildroot}%{_bindir}
install -d -m 0755 %{buildroot}%{_datadir}/%{name}
install -d -m 0755 %{buildroot}%{_datadir}/applications
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
install -d -m 0755 %{buildroot}%{_mandir}/man1/

install -d -m 0755 %{buildroot}%{_javadir}
install build/%{name}.jar %{buildroot}%{_datadir}/%{name}/%{name}.jar
# link /usr/share/jedit/jedit.jar to /usr/share/java
(cd %{buildroot}%{_javadir} && ln -s %{_datadir}/%{name}/%{name}.jar %{name}.jar)

# Install the /usr/share/jedit subdirectories
cp -ar build/{doc,jars,keymaps,macros,modes,properties,startup} %{buildroot}%{_datadir}/%{name}

# Symlink the javadoc into /usr/share/jedit
(cd %{buildroot}%{_datadir}/%{name}/doc && ln -s %{_javadocdir}/%{name} api)

# Man page
install -m 0644 package-files/linux/%{name}.1 %{buildroot}%{_mandir}/man1/

# Icons
for size in 16 32 48 64 128 256; do
    dims="${size}x${size}"
    install -D -m 644 ../icons/icon_${dims}.png %{buildroot}%{_datadir}/icons/hicolor/${dims}/apps/%{name}.png
done

# Desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}

# Launcher script
cat %{SOURCE3} | sed 's|@data|%{_datadir}/%{name}|g' > %{name}
install %{name} %{buildroot}%{_bindir}

%fdupes -s %{buildroot}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%attr(0755,root,root) %{_bindir}/%{name}
%{_javadir}/%{name}.jar
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/icons/hicolor/
%exclude %{_datadir}/%{name}/doc

%files javadoc
%doc %{_javadocdir}/%{name}
%{_datadir}/%{name}/doc

%changelog
* Fri Apr 19 2024 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * jedit-doclet.patch
    + add -notimestamp parameter to javadoc for reproducible
    builds
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and terget levels 8
* Thu May 20 2021 Markéta Machová <mmachova@suse.com>
- Include all available docs in the javadoc subpackage
* Tue May 18 2021 Markéta Machová <mmachova@suse.com>
- Include pre-generated html docs, jEdit expects them (bsc#845615)
* Tue Feb  2 2021 Jan Engelhardt <jengelh@inai.de>
- Set buildshell to /bin/bash for "<<<".
* Sun Nov 10 2019 Fridrich Strba <fstrba@suse.com>
- Added patches:
  * jedit-doclet.patch
    + Do not use custom doclet
  * jedit-jdk9+.patch
    + Do not bail out on java >= 9
- Removed patches:
  * jedit-encoding.patch
  * jedit-jdk10.patch
    + Not needed anymore
* Sun Nov 10 2019 admin@damienradtke.org
- Upgrade to 5.5.0
  * updates jEdit to version 5.5.0 (the latest stable version),
    and makes some other small improvements such as support for
  larger application icons and antialiasing settings in the
  launch script.
* Mon Dec 10 2018 Fridrich Strba <fstrba@suse.com>
- Build against the generic provider xml-apis instead of
  xerces-j2-xml-apis
* Thu Nov  1 2018 Fridrich Strba <fstrba@suse.com>
- Port to use bsh2 instead of the old bsh
* Fri Dec 22 2017 fstrba@suse.com
- Added patch:
  * jedit-jdk10.patch
    + Fix building with jdk10
    + Do not use custom doclet APIs removed in jdk10
* Mon Sep 18 2017 fstrba@suse.com
- Added patch:
  * jedit-encoding.patch
    + fix javadoc generation with jdk9
* Mon Jul  7 2014 tchvatal@suse.com
- Version bump to 5.1.0:
  * Various updates all raound the place
  * Few api changes
  * http://www.jedit.org/CHANGES51.txt
* Mon Jul  7 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
* Mon Jul  7 2014 tchvatal@suse.com
- Fix jedit build with new xml-common-apis
* Mon Sep 30 2013 mvyskocil@suse.com
- fix a build, added missing commons-logging and junit
* Thu Mar  7 2013 admin@damienradtke.org
- updated build to use openSUSE-packaged dependencies
* Thu Jan 17 2013 admin@damienradtke.org
- update to 5.0.0
- fixed java version incompatability with openSUSE 12.1
- many bug fixes, API changes, editing and UI updates
- added missing documentation
- full changelog here: www.jedit.org/CHANGES50.txt
* Wed Jun 27 2012 mvyskocil@suse.cz
- update to 4.5.1 (bugfix release)
- build it from source and don't bundle everything in a tarball
- strip documentation build and install as it's extremly complicated and needs
  a lot of dependencies
- reworked launcher script
* Sun Jun 17 2012 factory-maintainer@kulow.org
- adding deps.sh as source
* Wed Feb 29 2012 admin@damienradtke.org
- Update to 4.5.0
  * Performance improvements.
  * Elastic tabstop option now available.
  * Lots of old deprecated API's were removed.
  * Choose color ordering for subpixel antialising.
  * Desktop system tray icon added.
  * It is now possible to change look & feel without restarting jEdit.
  * It is now possible to specify a FILE_NAME_GLOB for an edit mode
    based on the full path.
  * File System Browser can now open files in desktop, using filename
    associations to launch another program.
  * Plugin Manager enhancements, filter field, bugs fixed.
* Thu Jan 12 2012 mvyskocil@suse.cz
- Update to 4.4.2
  * a lot of bugfixes
  * `elsif compiler directive added to verilog edit mode (#3261277)
  (Matthieu Casanova)
  * Methods to manage the cursor if the TextArea
  * Introduction of a new ThreadUtilities class implementing a
    threadpool using Java 1.6 Concurrent API.
  * File System Browser dynamic menu support (#2938170 - François Rey)
  * BufferSet api rewritten. Now each editPane have its own bufferSet,
    does not share it with other editPanes. The bufferset scope is the
  * Status bar widget : it is now possible to use labels starting with letters
    in status bar. (Matthieu Casanova)
  * Update for Stata-edit mode (goebbe, # 3019042)
  * Added "using" keyword to haXe edit mode (patch #3081482 from Bad Sector,
    Matthieu Casanova)
* Sun May 22 2011 idonmez@novell.com
- Don't hardcode docbook-xsl-stylesheet version
* Wed Aug 11 2010 mvyskocil@suse.cz
- Update to 4.3.2
  * a lot of bugfixes
  * improved indenting rules of Python edit mode (Björn "Vampire" Kautler)
  * New options to select the width and the background color of the selection area
    in the gutter (which is visible when line numbers are not shown).
  * New button in Hypersearch dockable panel to stop an hypersearch
    (patch #2842444) (encorejane)
  * New Macro - "Text/Compose Tag". (Gordon Hollenbeck # 2644277)
  * New (restored?) Actions: dumb "home" and "end": not as smart as smart
    home/end - stays on the same line always. (Alan Ezust)
  * Smarter Smart-end - uses syntax info to determine end of code (before
    start of comment), giving smart-end 4 states instead of the previous 3.
    (Gordon Hollenbeck #2646484).
  * and many more - see CHANGES.txt
- fix bnc#629375 - jedit does not work because of wrong version of bsh2
  * jedit needs patched version of bsh2, we used the vanilla sources from
    bsh2-src package, apply patches from Debian and use the modified version
    for build
* Tue Dec 15 2009 mvyskocil@suse.cz
- fixed build with bsh-2.0b5
  * added jedit-4.2-bsh-2.0b5.patch
* Tue Mar 10 2009 ro@suse.de
- ignore some subshell return values to fix build for now
* Thu Aug  7 2008 mvyskocil@suse.cz
- fixed a name clash under java6
- fix some rpmlint warnings:
  - bzipped source tarball
  - fix duplicates using fdupes
  - add a provides jedit-rhmenu  antlr-jedit
- quiet option to setup macro
* Tue Jan 29 2008 mmaher@suse.de
- added TextTools Plugin (#276446)
  The TextTools plugin provides a set of plugin actions for
    manipulating text in a buffer.
* Fri Mar  9 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Mon Sep 25 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov  3 2005 jsmeix@suse.de
- added Obsoletes for antlr-jedit because since jedit version 4.2
  /usr/share/jedit/modes/antlr.xml is included in jedit.
* Wed Oct 19 2005 jsmeix@suse.de
- Current version 4.2 from JPackage.org
* Tue Aug  9 2005 mls@suse.de
- removed compat from neededforbuild
* Mon Sep 13 2004 ro@suse.de
- removed apache-ant from neededforbuild
- added to neededforbuild: ant,xml-commons-apis,jpackage-utils
  update-alternatives,xerces-j2
* Mon Mar  8 2004 pmladek@suse.cz
- updated to version 4.1
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Sep 19 2003 pmladek@suse.cz
- renamed the link /usr/share/doc/packages/jedit/users-guide to
  fix the update from older distributions [#31307]
* Mon Jul 14 2003 pmladek@suse.cz
- fixed neededforbuild due to the renamed package jakarta-ant -> apache-ant
* Fri Jan 31 2003 pmladek@suse.cz
- updated BufferTabs plugin to version 0.7.8
- fixed jedit wrapper to require at least a JRE version 1.3,
  but to do not require exactly this version
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
- changed neededforbuild <sp> to <opensp>
* Mon Aug  5 2002 pmladek@suse.cz
- updated to version 4.0.3 with many improvents and bug fixes
- updated InfoViewer plugin to version 1.1
- removed obsolete patch
- removed obsolete EditBus plugin (it is included in jedit now)
- fixed jedit launcher to select strict java version 1.3.x
- fixed neededforbuild
* Thu Feb  7 2002 pmladek@suse.cz
- updated plugins:
  * BufferTabs to version 0.7.6
  * InfoViewer to version 1.0
- removed the plugin QuickNotepad, it does not work
- only plugins with makefile.jmk are compiled from sources
* Fri Nov 30 2001 ro@suse.de
- changed neededforbuild <docbktls> to <docbook-toys>
* Tue Nov 20 2001 pmladek@suse.cz
- fixed silly messages on start
* Tue Oct 30 2001 pmladek@suse.cz
- package creadted, version 3.2.2
